@@ -1,29 +1,29 @@
 /*
-  * Clutter-GStreamer.
-  *
-  * GStreamer integration library for Clutter.
-  *
-  * clutter-gst-auto-video-sink.c - GStreamer Auto Clutter Video Sink bin.
-  *
-  * Authored by Josep Torra  <support@fluendo.com>
-  *
-  * Copyright (C) 2011 Fluendo, S.A.
-  *
-  * This library is free software; you can redistribute it and/or
-  * modify it under the terms of the GNU Lesser General Public
-  * License as published by the Free Software Foundation; either
-  * version 2 of the License, or (at your option) any later version.
-  *
-  * This library is distributed in the hope that it will be useful,
-  * but WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * Lesser General Public License for more details.
-  *
-  * You should have received a copy of the GNU Lesser General Public
-  * License along with this library; if not, write to the
-  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  * Boston, MA 02111-1307, USA.
-  */
+ * Clutter-GStreamer.
+ *
+ * GStreamer integration library for Clutter.
+ *
+ * clutter-gst-auto-video-sink.c - GStreamer Auto Clutter Video Sink bin.
+ *
+ * Authored by Josep Torra  <support@fluendo.com>
+ *
+ * Copyright (C) 2011 Fluendo, S.A.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
 
 #ifndef __CLUTTER_GST_AUTO_VIDEO_SINK_H__
 #define __CLUTTER_GST_AUTO_VIDEO_SINK_H__
@@ -32,7 +32,8 @@
 #include <clutter/clutter.h>
 
 G_BEGIN_DECLS
-#define CLUTTER_GST_TYPE_AUTO_VIDEO_SINK clutter_gst_auto_video_sink_get_type()
+
+#define CLUTTER_GST_TYPE_AUTO_VIDEO_SINK (clutter_gst_auto_video_sink_get_type())
 
 #define CLUTTER_GST_AUTO_VIDEO_SINK(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST((obj), \
@@ -64,7 +65,7 @@ G_BEGIN_DECLS
     GST_LOG_OBJECT (obj,                                                \
                     "locking from thread %p",                           \
                     g_thread_self ());                                  \
-    g_mutex_lock (CLUTTER_GST_AUTO_VIDEO_SINK(obj)->lock);              \
+    g_mutex_lock (&CLUTTER_GST_AUTO_VIDEO_SINK(obj)->lock);              \
     GST_LOG_OBJECT (obj,                                                \
                     "locked from thread %p",                            \
                     g_thread_self ());                                  \
@@ -74,7 +75,7 @@ G_BEGIN_DECLS
     GST_LOG_OBJECT (obj,                                                \
                     "unlocking from thread %p",                         \
                     g_thread_self ());                                  \
-    g_mutex_unlock (CLUTTER_GST_AUTO_VIDEO_SINK(obj)->lock);            \
+    g_mutex_unlock (&CLUTTER_GST_AUTO_VIDEO_SINK(obj)->lock);            \
 } G_STMT_END
 
 typedef struct _ClutterGstAutoVideoSink ClutterGstAutoVideoSink;
@@ -86,7 +87,7 @@ struct _ClutterGstAutoVideoSink
 
   GstPad *sink_pad;
   GstPad *sink_block_pad;
-  GstPadSetCapsFunction sink_setcaps;
+  guint sink_block_id;
 
   GstElement *child;
 
@@ -99,7 +100,7 @@ struct _ClutterGstAutoVideoSink
 
   ClutterTexture *texture;
 
-  GMutex *lock;
+  GMutex lock;
 };
 
 struct _ClutterGstAutoVideoSinkClass
